@@ -214,3 +214,8 @@ test_that("translate sql server -> sqlite DROP TABLE IF EXISTS", {
   sql <- translate("DROP TABLE IF EXISTS test;", targetDialect = "sqlite")
   expect_equal_ignore_spaces(sql, "DROP TABLE IF EXISTS test;")
 })
+
+test_that("translate sql server -> sqlite IIF", {
+  sql <- translate("SELECT IIF(a>b, 1, b) AS max_val FROM table;", targetDialect = "sqlite")
+  expect_equal_ignore_spaces(sql, "SELECT CASE WHEN a>b THEN 1 ELSE b END AS max_val FROM table ;")
+})
